@@ -60,10 +60,14 @@ fitted.bas = function(object,  type="HPM", top=NULL, ...) {
   nmodels = length(object$which)
   X = object$X
   if (type=="HPM") {
-    X = cbind(1,sweep(X[,-1], 2, object$mean.x))
-    best =  min((1:nmodels)[object$logmarg == max(object$logmarg)])
-    yhat  <- as.vector(X[,object$which[[best]]+1, drop=FALSE] %*% object$mle[[best]]) * object$shrinkage[[best]]
-    yhat = yhat + (1 - object$shrinkage[[best]])*(object$mle[[best]])[1]
+#    X = cbind(1,sweep(X[,-1], 2, object$mean.x))
+#    best =  which.max(object$logmarg)
+#    yhat  <- as.vector(X[,object$which[[best]]+1, drop=FALSE] %*% object$mle[[best]]) * object$shrinkage[[best]]
+ #   yhat = yhat + (1 - object$shrinkage[[best]])*(object$mle[[best]])[1]
+      ypred = predict(object, X, 1)
+      best = ypred$best
+      yhat = ypred$Ybma   # note with ome model this is the HPM
+      attributes(yhat) = list(model = unlist(object$which[best]), best=best)   
   }
   if (type == "BMA") {
    yhat = predict(object, X, top)$Ybma
@@ -84,7 +88,16 @@ fitted.bas = function(object,  type="HPM", top=NULL, ...) {
      yhat  <- as.vector(X[,object$which[[best]]+1, drop=FALSE] %*% object$mle[[best]]) * object$shrinkage[[best]]
      yhat = yhat + (1 - object$shrinkage[[best]])*(object$mle[[best]])[1]
  }
-  else { yhat = rep(nrow(X), 1) * as.numeric(object$mle[object$size == 1])}
+   else { yhat = rep(nrow(X), 1) * as.numeric(object$mle[object$size == 1])}
+   attributes(yhat) = list(model = bestmodel)   
 }
+  if (type=="BPM") {
+      ypred = predict(object, X, top)
+      dis =apply(sweep(ypred$Ypred, 2, ypred$Ybma),1, sd)
+      best = which.min(dis)
+      yhat = ypred$Ypred[best, ]
+      attributes(yhat) = list(model = unlist(object$which[ypred$best[best]]),
+                    best = ypred$best[best])
+  }
 return(yhat)
 }
